@@ -28,12 +28,7 @@ class Pipe(Component, LocalEvents):
 
     def drop(self, message):
         if isinstance(message, Message):
-            try:
-                # self.debug(f'--- dropping {message}')
-                message.drop(self)
-            except Exception:
-                __import__('pudb').set_trace()
-                raise
+            message.drop(self)
 
     async def receive(self, **kwargs):
         raise NotImplementedError(f'{self}.receive()')
@@ -119,36 +114,12 @@ class Manifold(Pipe):
         return '<%s [%s]>' % (self.__class__.__name__,
                               ', '.join('%s:%s' % (n, p.id)
                                         for n, p in self.channels.items()))
-        # ', '.join('%s:%s' % (n, p.get('id', f'--{p}'))
 
     _dependent_statuses = set()
 
     def start(self):
         return asyncio.gather(super().start(), *(c.start() for c in self.children))
 
-    async def Xrun(self):
-        await super().run()
-        self.status = 'running'
-        # self.debug('- starting pipes')
-        # __import__('pudb').set_trace()
-        for pipe in self.channels.values():
-            if not pipe.running:
-                self.debug(f'*** pipe not running {pipe} {pipe.start}')
-                # await pipe.start()
-            else:
-                self.debug(f'*** pipe already running {pipe}')
-        # self.debug('- watching pipes')
-        # running = True
-        # while running:
-        #     await asyncio.sleep(0.1)
-        #     running = False
-        #     for pipe in self.channels.values():
-        #         running = running or pipe.running
-        #         if running:
-        #             break
-        # self.debug('- pipes stopped')
-        self.ready.set()
-
 
 class NullPipe(Pipe):
     async def send(self, message, **kwargs):
@@ -162,7 +133,6 @@ class NullPipe(Pipe):
             yield
 
 
-# class FeederPipe(Pipe):
 class DataPipe(Pipe):
     """Outputs preloaded messages, in order."""
 
@@ -196,15 +166,11 @@ class QueuePipe(Pipe):
 
     async def receive(self, wait=True):
         if not self.running:
-            # self.debug('*** not receiving since not running')
             return EOT
 
         if wait:
-            # self.debug('*** reading from queue (waiting)')
             message = await self._queue.get()
-            # self.debug(f'*** read from queue: {message}')
         else:
-            # self.debug('*** reading from queue (no wait)')
             message = self._queue.get_nowait()
         if message == EOT:
             self.status = 'finished'
